package orsetto

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class type Basic.prioritizer

The class type of prioritizer classes. Defines methods for converting priority levels into 1) their corresponding code, and 2) their corresponding message tag.

method code : 'level -> int

Use p#code v to convert the priority level v to a priority code with the prioritizer p.

method tag : 'level -> string

Use p#tag v to convert the priority level v to a message tag with the prioritizer p.