package orsetto

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class type Cf_stdtime.epoch

The class type inhabited by object types representing time stamps qualified with an integral offset from local time to UTC in minutes.

inherit unqualified
method offset : int